@@ -4,8 +4,8 @@ __author__ = ('Aitor Blanco Miguez (aitor.blancomiguez@unitn.it), '
               'Francesco Asnicar (f.asnicar@unitn.it), '
               'Moreno Zolfo (moreno.zolfo@unitn.it), '
               'Francesco Beghini (francesco.beghini@unitn.it)')
-__version__ = '3.0.8'
-__date__ = '7 May 2021'
+__version__ = '3.0.11'
+__date__ = '07 Jul 2021'
 
 import sys
 try:
@@ -27,8 +27,12 @@ try:
 except ImportError:
     from external_exec import generate_markers_fasta
 
-DEFAULT_DATABASE = os.path.join(os.path.dirname(os.path.abspath(__file__)), 
-    "../metaphlan_databases/mpa_v30_CHOCOPhlAn_201901.pkl")
+# get the directory that contains this script
+metaphlan_script_install_folder = os.path.dirname(os.path.abspath(__file__))
+DEFAULT_DB_FOLDER = os.path.join(metaphlan_script_install_folder, "../metaphlan_databases")
+DEFAULT_DB_FOLDER = os.environ.get('METAPHLAN_DB_DIR', DEFAULT_DB_FOLDER)
+DEFAULT_DB_NAME =  "mpa_v30_CHOCOPhlAn_201901.pkl"
+DEFAULT_DATABASE = os.path.join(DEFAULT_DB_FOLDER, DEFAULT_DB_NAME)
 
 """
 Reads and parses the command line arguments of the script.
@@ -36,9 +40,9 @@ Reads and parses the command line arguments of the script.
 :returns: the parsed arguments
 """
 def read_params():
-    p = ap.ArgumentParser(description="")
+    p = ap.ArgumentParser(description="", formatter_class=ap.ArgumentDefaultsHelpFormatter)
     p.add_argument('-d', '--database', type=str, default=DEFAULT_DATABASE,
-                   help="The input MetaPhlAn dtabase")
+                   help="The input MetaPhlAn database")
     p.add_argument('-c', '--clade', type=str, default=None,
                    help="The clades to investigate")
     p.add_argument('-o', '--output_dir', type=str, default=None,
@@ -59,6 +63,9 @@ def check_params(args):
     elif not args.output_dir:
         error('-o (or --output_dir) must be specified', exit=True, 
             init_new_line=True)
+    elif not os.path.exists(args.output_dir):
+        error('The directory {} does not exist'.format(args.output_dir), exit=True, 
+            init_new_line=True)
     elif not os.path.exists(args.database):
         error('The database does not exist', exit=True, 
             init_new_line=True)
@@ -89,8 +96,6 @@ Extract the markers of a specific clade in a MetaPhlAn database
 :returns: the output file with the extracted sequences of the marker
 """
 def extract_markers(database, clade, output_dir):
-    if not os.path.exists(output_dir):
-        os.mkdir(output_dir)
     info('\tGenerating DB markers FASTA...', init_new_line=True)
     fasta_markers = generate_markers_fasta(database, output_dir)
     info('\tDone.', init_new_line=True)
